#ifndef _ALSTRING_
#define _ALSTRING_

#include <iostream>
#include <cstring>
#include <stddef.h>
#include <stdlib.h>

using namespace std;

/**
 * Kapselt eine Zeichenkette (const char *).
 * Stellt Operationen fr Vergleiche und Zuweisungen zur Verfgung.
 */

class AlString
{
	public:
		// Konstruktoren
		
		/// Erzeugt ein AlString Objekt mit leerem String. 
		AlString(void);
		/** Erzeugt ein AlString Objekt mit dem bergebenen String.
		 * @param String String, mit dem die Instanz gefllt wird.
		 */
		AlString(const char *String);

		// Methoden
		
		/** Liefert den Inhalt der AlString Klasse zurck.
		 * @return Zeiger auf den Anfang der enthaltenen Zeichenkette.
		 */
		char *getText();
		/** Setzt den Inhalt der AlString Klasse neu. Dasselbe wie =.
		 * @param String String, mit dem die Instanz gefllt wird.
		 */
		void setText(const char *String);
		/**
		 * Liefert die Lnge des Strings ohne das abschliessende \0.
		 * @return Anzahl der enthaltenen Zeichen als size_t.
		 */
		size_t getLength();
		/**
		 * Vergleicht diese Instanz mit einer anderen.
		 * Das Ergebnis ist dasselbe wie bei strcmp().
		 * @param String Zu vergleichende AlString Instanz.
		 * @return Ein Wert wie bei strcmp().
		 * =0 - wenn die Strings gleich sind.
		 * >0 - wenn die aktuelle Instanz grsser ist.
		 * <0 - wenn die aktuelle Instanz kleiner ist.
		 */
		int compare(AlString String);
		/**
		 * Vergleicht diese Instanz mit einer Zeichenkette.
		 * @param String Zu vergleichende Zeichenkette.
		 * @return Ein Wert wie bei strcmp().
		 * =0 - wenn die Strings gleich sind.
		 * >0 - wenn die aktuelle Instanz grsser ist.
		 * <0 - wenn die aktuelle Instanz kleiner ist.
		 */
		int compare(const char *String);

		/**
		 * Wandelt den String in eine int Zahl um (wie atoi).
		 * @return Eine int Zahl, die den Inhalt des Strings reprsentiert.
		 */
		int toInt();

		/**
		 * Wandelt den String in eine long Zahl um (wie atol).
		 * @return Eine long Zahl, die den Inhalt des Strings reprsentiert.
		 */
		long toLong();

		/**
		 * Wandelt den String in eine double Zahl um (wie atof).
		 * @return Eine double Zahl, die den Inhalt des Strings reprntiert.
		 */
		double toDouble();
		
		// Operatoren
		
		void operator=(const char *String);
		void operator=(AlString String);
		void operator+=(AlString String);
		void operator+=(const char *String);
		bool operator<(AlString String);
		bool operator<(const char *String);
		bool operator>(AlString String);
		bool operator>(const char *String);
		bool operator==(AlString String);
		bool operator==(const char *String);
		bool operator!=(AlString String);
		bool operator!=(const char *String);
		AlString operator+(AlString String);
		AlString operator+(const char *String);

	private:
		// Attribute
		
		char *InnerString;
};

ostream& operator<<(ostream& os, AlString String);

#endif
